""" model_evaluation.py
AE3M33UI - Artificial Intelligence course, FEE CTU in Prague

Module contains functions for predictive model evaluation.
"""

import numpy as np
from sklearn import cross_validation


def compute_err_MSE(y, yhat):
    """Compute the mean squared error from the predictions and true values."""
    diffs = y-yhat
    total_err = diffs.dot(diffs.T)
    return total_err / y.shape[0]


def compute_err_01(y, yhat):
    """Compute the zero-one error, i.e. the misclassification rate."""
    diffs = y != yhat
    return sum(diffs) / y.shape[0]


def compute_model_error(model, X, y, err_func):
    """Compute the error of the model using the given data and error function.
    """
    ypred = model.predict(X)
    return err_func(y, ypred)


def compute_learning_curve(model, tr_sizes, Xtr, ytr, Xtst, ytst):
    """Compute a single learning curve."""
    # Pre-allocate the arrays for computed errors
    tr_errors = np.zeros_like(tr_sizes, dtype=np.float)
    tst_errors = np.zeros_like(tr_sizes, dtype=np.float)

    raise NotImplementedError
    # <YOUR CODE HERE>

    return tr_errors, tst_errors
